==> KleckFiles(5.98.00).zip: KleckFiles/wiki/page/vatican.js <==
var wikiMetaData = {created:'231111', modified:'231111'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>The Vatican</h1>",
"<p>The Catholic church is the largest church in the world that calls itself Christian.",
"</p>",
	
'<p>I collected some Vatican images here: <a href="index.html?cover" target="_blank"><b>Vatican Tour</b></a>',
'<br>Honestly once you look at the artwork and archetecture with a critical eye and ask why? You will never look at it the same again.</p>',
	
'<div class="pageTOC" id="pageTOC"></div>',
"<br>",
	
'<h2 class="pageTOC">Singing to Lucifer</h2>',
"<p>In this short video why are 6 priests singing to Lucifer?</p>",
'<div class="_w_EmbedKFVideo" id="video_221115-03"></div>',

"<br>",

'<h2 class="pageTOC">List of popes</h2>',
"<p>WHY Is there SCULTURE of a HUMAN in AGONY Under the List of POPES?</p>",
'<div class="_w_EmbedKFVideo" id="video_211017-02"></div>',

"<br>",
	
'<h2 class="pageTOC">WHY is the VATICAN BUILT to RESEMBLE a SERPENT WEARING A CROWN?</h2>',
'<p>The word “Vatican” literally means “Divining Serpent,” and is derived from Vatis = Diviner ',
'and Can = Serpent. Vatican City and St. Peter’s Basilica were built on the ancient pagan site called ',
'in Latin vaticanus mons or vaticanus colli, which means hill or mountain of prophecy.</p>',
'<div class="_w_EmbedKFVideo" id="video_211018-03"></div>',
	
"<br>",

'<h2 class="pageTOC">A Sober look at the Serpent Church</h2>',
"<p>Jonathan at a low point of exhaustion reveiws the Vatican and Serpent system one more time.</p>",
'<div class="_w_EmbedKFVideo" id="video_211024"></div>',

"<br>",
	
'<h2 class="pageTOC">Short and to the point</h2>',
"<p>Jonathan's short and sharable videos exploring the Serpent Race and Serpent World. </p>",
'<div class="_w_EmbedKFVideo" id="video_230725-02"></div>',
'<br><div class="_w_EmbedKFVideo" id="video_230806-01"></div>',
'<br><div class="_w_EmbedKFVideo" id="video_230810"></div>',

"<br>",

'<h2 class="pageTOC">Walter Veith Sermon - THE Islamic Connection</h2>',
"<p>I add this video for anyone unaware of how vast the serpent kingdom is. Islam, Vatican, Jesuits .. its all the same thing dressed in different costumes.",
"The one world religion is here already. Choosing a unifying name is just a formality now. We all worship God they say. Which God?</p>",
'<div class="_w_EmbedKFVideo" id="video_230918-P15"></div>',
	
	
	

""
];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/page/vatican.js <==
var wikiMetaData = {created:'231111', modified:'231111'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>The Vatican</h1>",
'<p>Here are some Vatican related videos. Take the <a href="index.html?cover" target="_blank"><b>Vatican Tour</b></a></p>',
	
'<div class="pageTOC" id="pageTOC"></div>',
"<br>",
	
'<h2 class="pageTOC">Singing to Lucifer</h2>',
"<p>In this short video why are 6 priests singing to Lucifer?</p>",
'<div class="_w_EmbedKFVideo" id="video_221115-03"></div>',

"<br>",

'<h2 class="pageTOC">List of popes</h2>',
"<p>WHY Is there SCULTURE of a HUMAN in AGONY Under the List of POPES?</p>",
'<div class="_w_EmbedKFVideo" id="video_211017-02"></div>',

"<br>",
	
'<h2 class="pageTOC">WHY is the VATICAN BUILT to RESEMBLE a SERPENT WEARING A CROWN?</h2>',
'<p>The word “Vatican” literally means “Divining Serpent,” and is derived from Vatis = Diviner ',
'and Can = Serpent. Vatican City and St. Peter’s Basilica were built on the ancient pagan site called ',
'in Latin vaticanus mons or vaticanus colli, which means hill or mountain of prophecy.</p>',
'<div class="_w_EmbedKFVideo" id="video_211018-03"></div>',
	
"<br>",

'<h2 class="pageTOC">A Sober look at the Serpent Church</h2>',
"<p>Jonathan at a low point of exhaustion reveiws the Vatican and Serpent system one more time.</p>",
'<div class="_w_EmbedKFVideo" id="video_211024"></div>',

"<br>",
	
'<h2 class="pageTOC">Short and to the point</h2>',
"<p>Jonathan's short and sharable videos exploring the Serpent Race and Serpent World. </p>",
'<div class="_w_EmbedKFVideo" id="video_230725-02"></div>',
'<br><div class="_w_EmbedKFVideo" id="video_230806-01"></div>',
'<br><div class="_w_EmbedKFVideo" id="video_230810"></div>',

"<br>",

'<h2 class="pageTOC">Walter Veith Sermon - THE Islamic Connection</h2>',
"<p>I add this video for anyone unaware of how Islam, Vatican, Jesuits .. all the same thing dressed in different costumes.",
"The one world religion is here already. We all worship God they say. Which God?</p>",
'<div class="_w_EmbedKFVideo" id="video_230918-P15"></div>',
	
	
	

""
];
